prompt --application/set_environment
set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_180200 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2018.05.24'
,p_release=>'18.2.0.00.12'
,p_default_workspace_id=>1549777203957536
,p_default_application_id=>100
,p_default_owner=>'APEX_UTILS'
);
end;
/
prompt --application/shared_components/plugins/dynamic_action/com_apexutils_changespinner
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(50132478039169497)
,p_plugin_type=>'DYNAMIC ACTION'
,p_name=>'COM.APEXUTILS.CHANGESPINNER'
,p_display_name=>'APEX Utils - Change Spinner'
,p_category=>'MISC'
,p_supported_ui_types=>'DESKTOP:JQM_SMARTPHONE'
,p_plsql_code=>wwv_flow_string.join(wwv_flow_t_varchar2(
'/*------------------------------------------------------------------------------',
' * Author       Stefan Dobre',
' * Created      01.06.2019',
' *',
' * Description  Dynamic Action plug-in to change the default APEX spinner,',
' *              by providing custom HTML and CSS.',
' *',
' * License      MIT ',
' *------------------------------------------------------------------------------',
' * Modification History',
' *',
' * 18.06.2019   v1.1 fixed issue on modal page',
' * 01.06.2019   v1.0 initial release',
' */-----------------------------------------------------------------------------',
'',
'function render',
'    ( p_dynamic_action in apex_plugin.t_dynamic_action',
'    , p_plugin         in apex_plugin.t_plugin',
'    )',
'return apex_plugin.t_dynamic_action_render_result',
'as',
'    l_result apex_plugin.t_dynamic_action_render_result;',
'begin',
'',
'    apex_javascript.add_library',
'        ( p_name       => ''script#MIN#''',
'        , p_directory  => nvl(:G_APEX_UTILS_APEX_NITRO_IMAGES, p_plugin.file_prefix) || ''js/''',
'        );',
'',
'    l_result.javascript_function := ''apexUtils.changeSpinner'';',
'    ',
'    l_result.attribute_01 := p_dynamic_action.attribute_01; --html',
'    l_result.attribute_02 := p_dynamic_action.attribute_02; --css',
'',
'    return l_result;',
'end;'))
,p_api_version=>2
,p_render_function=>'render'
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_help_text=>'<p>Dynamic Action plug-in to change the default APEX spinner, by providing custom HTML and CSS.</p>'
,p_version_identifier=>'1.1'
,p_about_url=>'https://www.apexutils.com'
,p_files_version=>38
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(50132647880169556)
,p_plugin_id=>wwv_flow_api.id(50132478039169497)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'Spinner HTML'
,p_attribute_type=>'HTML'
,p_is_required=>true
,p_is_translatable=>false
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>Provide the custom spinner as HTML.</p>',
'<p>You can find many examples online. Some search keywords could be: loader, spinner, html, css</p>'))
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(50133038321169559)
,p_plugin_id=>wwv_flow_api.id(50132478039169497)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>20
,p_prompt=>'Spinner CSS'
,p_attribute_type=>'TEXTAREA'
,p_is_required=>false
,p_is_translatable=>false
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>Your custom spinner probably requires some fancy CSS. This is the place for it.</p>',
'<p>The CSS will be injected into the page <code>head</code> element when the DA fires.</p>'))
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '77696E646F772E617065785574696C73203D2077696E646F772E617065785574696C73207C7C207B7D3B0A77696E646F772E617065785574696C732E6368616E67655370696E6E6572203D2066756E6374696F6E28297B0A0A09766172207370696E6E65';
wwv_flow_api.g_varchar2_table(2) := '7248544D4C203D20746869732E616374696F6E2E61747472696275746530313B0A09766172207370696E6E657243535320203D20746869732E616374696F6E2E61747472696275746530323B0A0A092F2F4F76657277726974696E6720617065782E7574';
wwv_flow_api.g_varchar2_table(3) := '696C2E73686F775370696E6E65722077697468206120637573746F6D205370696E6E65720A092F2F746865206F6E6C79206368616E67657320746F20746865206F726967696E616C2066756E6374696F6E202874616B656E2066726F6D2031392E312920';
wwv_flow_api.g_varchar2_table(4) := '6172653A0A092F2F09746865206D61726B7570206F66206C5370696E6E6572240A092F2F2020696E6A656374696E672074686520637573746F6D206373730A0A09617065782E7574696C2E73686F775370696E6E6572203D2066756E6374696F6E282070';
wwv_flow_api.g_varchar2_table(5) := '436F6E7461696E65722C20704F7074696F6E732029207B0A0920202020766172206C5370696E6E6572242C206C4C6566742C206C546F702C206C426F74746F6D2C206C59506F736974696F6E2C206C594F66667365742C0A0920202020202020206F7574';
wwv_flow_api.g_varchar2_table(6) := '2020202020202020203D20617065782E7574696C2E68746D6C4275696C64657228292C0A0920202020202020206C4F7074696F6E73202020203D20242E657874656E6420287B0A09202020202020202020202020616C6572743A20202020202020202020';
wwv_flow_api.g_varchar2_table(7) := '617065782E6C616E672E6765744D657373616765282022415045582E50524F43455353494E472220292C0A092020202020202020202020207370696E6E6572436C6173733A20202022220A0920202020202020207D2C20704F7074696F6E7320292C0A09';
wwv_flow_api.g_varchar2_table(8) := '20202020202020206C436F6E7461696E657224203D20282070436F6E7461696E657220262620216C4F7074696F6E732E66697865642029203F2024282070436F6E7461696E65722029203A2024282022626F64792220292C0A0920202020202020206C57';
wwv_flow_api.g_varchar2_table(9) := '696E646F7724202020203D2024282077696E646F7720292C0A0920202020202020206C436F6E7461696E657220203D206C436F6E7461696E6572242E6F666673657428292C0A0920202020202020206C56696577706F72742020203D207B0A0920202020';
wwv_flow_api.g_varchar2_table(10) := '2020202020202020746F703A20206C57696E646F77242E7363726F6C6C546F7028292C0A092020202020202020202020206C6566743A206C57696E646F77242E7363726F6C6C4C65667428290A0920202020202020207D3B0A0A09202020202F2F636861';
wwv_flow_api.g_varchar2_table(11) := '6E67652031207374617274732068657265202D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D0A09202020207370696E6E657248544D4C203D207370696E6E657248544D4C2E7265706C616365282F23414C455254232F67';
wwv_flow_api.g_varchar2_table(12) := '2C206C4F7074696F6E732E616C657274293B0A09202020207370696E6E657248544D4C203D207370696E6E657248544D4C2E7265706C616365282F235350494E4E4552434C415353232F672C206C4F7074696F6E732E7370696E6E6572436C617373293B';
wwv_flow_api.g_varchar2_table(13) := '0A0A09202020206C5370696E6E657224203D202428207370696E6E657248544D4C20293B0A0A09202020206C5370696E6E6572242E637373287B0A0920202020097A496E6465783A20323030302C0A092020202009626F7853697A696E673A2027626F72';
wwv_flow_api.g_varchar2_table(14) := '6465722D626F78272C0A092020202009646973706C61793A2027626C6F636B272C0A092020202009706F736974696F6E3A20276162736F6C757465270A09202020207D293B0A09202020202F2F6368616E6765203120656E64732068657265202D2D2D2D';
wwv_flow_api.g_varchar2_table(15) := '2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D0A0A09202020206C5370696E6E6572242E617070656E64546F28206C436F6E7461696E65722420293B0A0A092020202069662028206C4F7074696F6E732E6669786564202920';
wwv_flow_api.g_varchar2_table(16) := '7B0A0920202020202020206C546F70203D2028206C57696E646F77242E6865696768742829202D206C5370696E6E6572242E68656967687428292029202F20323B0A0920202020202020206C4C656674203D2028206C57696E646F77242E776964746828';
wwv_flow_api.g_varchar2_table(17) := '29202D206C5370696E6E6572242E776964746828292029202F20323B0A0920202020202020206C5370696E6E6572242E63737328207B0A09202020202020202020202020706F736974696F6E3A20226669786564222C0A09202020202020202020202020';
wwv_flow_api.g_varchar2_table(18) := '746F703A20206C546F70202B20227078222C0A092020202020202020202020206C6566743A206C4C656674202B2020227078220A0920202020202020207D20293B0A09202020207D20656C7365207B0A0920202020202020202F2F2043616C63756C6174';
wwv_flow_api.g_varchar2_table(19) := '652076696577706F727420626F74746F6D20616E642072696768740A0920202020202020206C56696577706F72742E626F74746F6D203D206C56696577706F72742E746F70202B206C57696E646F77242E68656967687428293B0A092020202020202020';
wwv_flow_api.g_varchar2_table(20) := '6C56696577706F72742E7269676874203D206C56696577706F72742E6C656674202B206C57696E646F77242E776964746828293B0A0A0920202020202020202F2F2043616C63756C61746520636F6E7461696E657220626F74746F6D20616E6420726967';
wwv_flow_api.g_varchar2_table(21) := '68740A0920202020202020206C436F6E7461696E65722E626F74746F6D203D206C436F6E7461696E65722E746F70202B206C436F6E7461696E6572242E6F7574657248656967687428293B0A0920202020202020206C436F6E7461696E65722E72696768';
wwv_flow_api.g_varchar2_table(22) := '74203D206C436F6E7461696E65722E6C656674202B206C436F6E7461696E6572242E6F75746572576964746828293B0A0A0920202020202020202F2F20496620746F70206F6620636F6E7461696E65722069732076697369626C652C2075736520746861';
wwv_flow_api.g_varchar2_table(23) := '742061732074686520746F702C206F7468657277697365207573652076696577706F727420746F700A09202020202020202069662028206C436F6E7461696E65722E746F70203E206C56696577706F72742E746F702029207B0A09202020202020202020';
wwv_flow_api.g_varchar2_table(24) := '2020206C546F70203D206C436F6E7461696E65722E746F703B0A0920202020202020207D20656C7365207B0A092020202020202020202020206C546F70203D206C56696577706F72742E746F703B0A0920202020202020207D0A0A092020202020202020';
wwv_flow_api.g_varchar2_table(25) := '2F2F20496620626F74746F6D206F6620636F6E7461696E65722069732076697369626C652C2075736520746861742061732074686520626F74746F6D2C206F7468657277697365207573652076696577706F727420626F74746F6D0A0920202020202020';
wwv_flow_api.g_varchar2_table(26) := '2069662028206C436F6E7461696E65722E626F74746F6D203C206C56696577706F72742E626F74746F6D2029207B0A092020202020202020202020206C426F74746F6D203D206C436F6E7461696E65722E626F74746F6D3B0A0920202020202020207D20';
wwv_flow_api.g_varchar2_table(27) := '656C7365207B0A092020202020202020202020206C426F74746F6D203D206C56696577706F72742E626F74746F6D3B0A0920202020202020207D0A0920202020202020206C59506F736974696F6E203D2028206C426F74746F6D202D206C546F70202920';
wwv_flow_api.g_varchar2_table(28) := '2F20323B0A0A0920202020202020202F2F20496620746F70206F6620636F6E7461696E6572206973206E6F742076697369626C652C205920706F736974696F6E206E6565647320746F2061646420616E206F666673657420657175616C2068696464656E';
wwv_flow_api.g_varchar2_table(29) := '20636F6E7461696E6572206865696768742C0A0920202020202020202F2F207468697320697320726571756972656420626563617573652077652061726520706F736974696F6E696E6720696E2074686520636F6E7461696E657220656C656D656E740A';
wwv_flow_api.g_varchar2_table(30) := '0920202020202020206C594F6666736574203D206C56696577706F72742E746F70202D206C436F6E7461696E65722E746F703B0A09202020202020202069662028206C594F6666736574203E20302029207B0A092020202020202020202020206C59506F';
wwv_flow_api.g_varchar2_table(31) := '736974696F6E203D206C59506F736974696F6E202B206C594F66667365743B0A0920202020202020207D0A0A0920202020202020206C5370696E6E6572242E706F736974696F6E287B0A092020202020202020202020206D793A20202020202020202022';
wwv_flow_api.g_varchar2_table(32) := '63656E746572222C0A0920202020202020202020202061743A202020202020202020226C6566742B35302520746F702B22202B206C59506F736974696F6E202B20227078222C0A092020202020202020202020206F663A2020202020202020206C436F6E';
wwv_flow_api.g_varchar2_table(33) := '7461696E6572242C0A09202020202020202020202020636F6C6C6973696F6E3A202022666974220A0920202020202020207D293B0A09202020207D0A0A092020202072657475726E206C5370696E6E6572243B0A097D3B0A0A0A0A092F2F6368616E6765';
wwv_flow_api.g_varchar2_table(34) := '2032207374617274732068657265202D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D0A0924282723617065782D7574696C732D7370696E6E65722D63737327292E72656D6F766528293B0A0A096966287370696E6E6572';
wwv_flow_api.g_varchar2_table(35) := '435353297B0A090976617220746F417070656E64203D20273C7374796C652069643D22617065782D7574696C732D7370696E6E65722D637373223E272B207370696E6E6572435353202B273C2F7374796C653E273B0A09092428276865616427292E6170';
wwv_flow_api.g_varchar2_table(36) := '70656E6428746F417070656E64293B0A097D0A092F2F6368616E6765203220656E64732068657265202D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D0A7D3B0A0A0A0A0A2F2F2320736F757263654D617070696E67';
wwv_flow_api.g_varchar2_table(37) := '55524C3D7363726970742E6A732E6D61700A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(50140151611339047)
,p_plugin_id=>wwv_flow_api.id(50132478039169497)
,p_file_name=>'js/script.js'
,p_mime_type=>'application/x-javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '77696E646F772E617065785574696C733D77696E646F772E617065785574696C737C7C7B7D2C77696E646F772E617065785574696C732E6368616E67655370696E6E65723D66756E6374696F6E28297B76617220743D746869732E616374696F6E2E6174';
wwv_flow_api.g_varchar2_table(2) := '7472696275746530312C653D746869732E616374696F6E2E61747472696275746530323B696628617065782E7574696C2E73686F775370696E6E65723D66756E6374696F6E28652C6F297B617065782E7574696C2E68746D6C4275696C64657228293B76';
wwv_flow_api.g_varchar2_table(3) := '617220692C702C732C6E2C6C2C613D242E657874656E64287B616C6572743A617065782E6C616E672E6765744D6573736167652822415045582E50524F43455353494E4722292C7370696E6E6572436C6173733A22227D2C6F292C723D65262621612E66';
wwv_flow_api.g_varchar2_table(4) := '697865643F242865293A242822626F647922292C643D242877696E646F77292C683D722E6F666673657428292C783D7B746F703A642E7363726F6C6C546F7028292C6C6566743A642E7363726F6C6C4C65667428297D3B72657475726E20743D28743D74';
wwv_flow_api.g_varchar2_table(5) := '2E7265706C616365282F23414C455254232F672C612E616C65727429292E7265706C616365282F235350494E4E4552434C415353232F672C612E7370696E6E6572436C617373292C28693D24287429292E637373287B7A496E6465783A3265332C626F78';
wwv_flow_api.g_varchar2_table(6) := '53697A696E673A22626F726465722D626F78222C646973706C61793A22626C6F636B222C706F736974696F6E3A226162736F6C757465227D292C692E617070656E64546F2872292C612E66697865643F28733D28642E68656967687428292D692E686569';
wwv_flow_api.g_varchar2_table(7) := '6768742829292F322C703D28642E776964746828292D692E77696474682829292F322C692E637373287B706F736974696F6E3A226669786564222C746F703A732B227078222C6C6566743A702B227078227D29293A28782E626F74746F6D3D782E746F70';
wwv_flow_api.g_varchar2_table(8) := '2B642E68656967687428292C782E72696768743D782E6C6566742B642E776964746828292C682E626F74746F6D3D682E746F702B722E6F7574657248656967687428292C682E72696768743D682E6C6566742B722E6F75746572576964746828292C733D';
wwv_flow_api.g_varchar2_table(9) := '682E746F703E782E746F703F682E746F703A782E746F702C6E3D2828682E626F74746F6D3C782E626F74746F6D3F682E626F74746F6D3A782E626F74746F6D292D73292F322C286C3D782E746F702D682E746F70293E302626286E2B3D6C292C692E706F';
wwv_flow_api.g_varchar2_table(10) := '736974696F6E287B6D793A2263656E746572222C61743A226C6566742B35302520746F702B222B6E2B227078222C6F663A722C636F6C6C6973696F6E3A22666974227D29292C697D2C24282223617065782D7574696C732D7370696E6E65722D63737322';
wwv_flow_api.g_varchar2_table(11) := '292E72656D6F766528292C65297B766172206F3D273C7374796C652069643D22617065782D7574696C732D7370696E6E65722D637373223E272B652B223C2F7374796C653E223B2428226865616422292E617070656E64286F297D7D3B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(50140469493339069)
,p_plugin_id=>wwv_flow_api.id(50132478039169497)
,p_file_name=>'js/script.min.js'
,p_mime_type=>'application/x-javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '7B2276657273696F6E223A332C226E616D6573223A5B5D2C226D617070696E6773223A22222C22736F7572636573223A5B227363726970742E6A73225D2C22736F7572636573436F6E74656E74223A5B2277696E646F772E617065785574696C73203D20';
wwv_flow_api.g_varchar2_table(2) := '77696E646F772E617065785574696C73207C7C207B7D3B5C6E77696E646F772E617065785574696C732E6368616E67655370696E6E6572203D2066756E6374696F6E28297B5C6E5C6E5C74766172207370696E6E657248544D4C203D20746869732E6163';
wwv_flow_api.g_varchar2_table(3) := '74696F6E2E61747472696275746530313B5C6E5C74766172207370696E6E657243535320203D20746869732E616374696F6E2E61747472696275746530323B5C6E5C6E5C742F2F4F76657277726974696E6720617065782E7574696C2E73686F77537069';
wwv_flow_api.g_varchar2_table(4) := '6E6E65722077697468206120637573746F6D205370696E6E65725C6E5C742F2F746865206F6E6C79206368616E67657320746F20746865206F726967696E616C2066756E6374696F6E202874616B656E2066726F6D2031392E3129206172653A5C6E5C74';
wwv_flow_api.g_varchar2_table(5) := '2F2F5C74746865206D61726B7570206F66206C5370696E6E6572245C6E5C742F2F2020696E6A656374696E672074686520637573746F6D206373735C6E5C6E5C74617065782E7574696C2E73686F775370696E6E6572203D2066756E6374696F6E282070';
wwv_flow_api.g_varchar2_table(6) := '436F6E7461696E65722C20704F7074696F6E732029207B5C6E5C7420202020766172206C5370696E6E6572242C206C4C6566742C206C546F702C206C426F74746F6D2C206C59506F736974696F6E2C206C594F66667365742C5C6E5C7420202020202020';
wwv_flow_api.g_varchar2_table(7) := '206F75742020202020202020203D20617065782E7574696C2E68746D6C4275696C64657228292C5C6E5C7420202020202020206C4F7074696F6E73202020203D20242E657874656E6420287B5C6E5C74202020202020202020202020616C6572743A2020';
wwv_flow_api.g_varchar2_table(8) := '2020202020202020617065782E6C616E672E6765744D65737361676528205C22415045582E50524F43455353494E475C2220292C5C6E5C742020202020202020202020207370696E6E6572436C6173733A2020205C225C225C6E5C742020202020202020';
wwv_flow_api.g_varchar2_table(9) := '7D2C20704F7074696F6E7320292C5C6E5C7420202020202020206C436F6E7461696E657224203D20282070436F6E7461696E657220262620216C4F7074696F6E732E66697865642029203F2024282070436F6E7461696E65722029203A202428205C2262';
wwv_flow_api.g_varchar2_table(10) := '6F64795C2220292C5C6E5C7420202020202020206C57696E646F7724202020203D2024282077696E646F7720292C5C6E5C7420202020202020206C436F6E7461696E657220203D206C436F6E7461696E6572242E6F666673657428292C5C6E5C74202020';
wwv_flow_api.g_varchar2_table(11) := '20202020206C56696577706F72742020203D207B5C6E5C74202020202020202020202020746F703A20206C57696E646F77242E7363726F6C6C546F7028292C5C6E5C742020202020202020202020206C6566743A206C57696E646F77242E7363726F6C6C';
wwv_flow_api.g_varchar2_table(12) := '4C65667428295C6E5C7420202020202020207D3B5C6E5C6E5C74202020202F2F6368616E67652031207374617274732068657265202D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D5C6E5C74202020207370696E6E6572';
wwv_flow_api.g_varchar2_table(13) := '48544D4C203D207370696E6E657248544D4C2E7265706C616365282F23414C455254232F672C206C4F7074696F6E732E616C657274293B5C6E5C74202020207370696E6E657248544D4C203D207370696E6E657248544D4C2E7265706C616365282F2353';
wwv_flow_api.g_varchar2_table(14) := '50494E4E4552434C415353232F672C206C4F7074696F6E732E7370696E6E6572436C617373293B5C6E5C6E5C74202020206C5370696E6E657224203D202428207370696E6E657248544D4C20293B5C6E5C6E5C74202020206C5370696E6E6572242E6373';
wwv_flow_api.g_varchar2_table(15) := '73287B5C6E5C74202020205C747A496E6465783A20323030302C5C6E5C74202020205C74626F7853697A696E673A2027626F726465722D626F78272C5C6E5C74202020205C74646973706C61793A2027626C6F636B272C5C6E5C74202020205C74706F73';
wwv_flow_api.g_varchar2_table(16) := '6974696F6E3A20276162736F6C757465275C6E5C74202020207D293B5C6E5C74202020202F2F6368616E6765203120656E64732068657265202D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D5C6E5C6E5C74202020';
wwv_flow_api.g_varchar2_table(17) := '206C5370696E6E6572242E617070656E64546F28206C436F6E7461696E65722420293B5C6E5C6E5C742020202069662028206C4F7074696F6E732E66697865642029207B5C6E5C7420202020202020206C546F70203D2028206C57696E646F77242E6865';
wwv_flow_api.g_varchar2_table(18) := '696768742829202D206C5370696E6E6572242E68656967687428292029202F20323B5C6E5C7420202020202020206C4C656674203D2028206C57696E646F77242E77696474682829202D206C5370696E6E6572242E776964746828292029202F20323B5C';
wwv_flow_api.g_varchar2_table(19) := '6E5C7420202020202020206C5370696E6E6572242E63737328207B5C6E5C74202020202020202020202020706F736974696F6E3A205C2266697865645C222C5C6E5C74202020202020202020202020746F703A20206C546F70202B205C2270785C222C5C';
wwv_flow_api.g_varchar2_table(20) := '6E5C742020202020202020202020206C6566743A206C4C656674202B20205C2270785C225C6E5C7420202020202020207D20293B5C6E5C74202020207D20656C7365207B5C6E5C7420202020202020202F2F2043616C63756C6174652076696577706F72';
wwv_flow_api.g_varchar2_table(21) := '7420626F74746F6D20616E642072696768745C6E5C7420202020202020206C56696577706F72742E626F74746F6D203D206C56696577706F72742E746F70202B206C57696E646F77242E68656967687428293B5C6E5C7420202020202020206C56696577';
wwv_flow_api.g_varchar2_table(22) := '706F72742E7269676874203D206C56696577706F72742E6C656674202B206C57696E646F77242E776964746828293B5C6E5C6E5C7420202020202020202F2F2043616C63756C61746520636F6E7461696E657220626F74746F6D20616E64207269676874';
wwv_flow_api.g_varchar2_table(23) := '5C6E5C7420202020202020206C436F6E7461696E65722E626F74746F6D203D206C436F6E7461696E65722E746F70202B206C436F6E7461696E6572242E6F7574657248656967687428293B5C6E5C7420202020202020206C436F6E7461696E65722E7269';
wwv_flow_api.g_varchar2_table(24) := '676874203D206C436F6E7461696E65722E6C656674202B206C436F6E7461696E6572242E6F75746572576964746828293B5C6E5C6E5C7420202020202020202F2F20496620746F70206F6620636F6E7461696E65722069732076697369626C652C207573';
wwv_flow_api.g_varchar2_table(25) := '6520746861742061732074686520746F702C206F7468657277697365207573652076696577706F727420746F705C6E5C74202020202020202069662028206C436F6E7461696E65722E746F70203E206C56696577706F72742E746F702029207B5C6E5C74';
wwv_flow_api.g_varchar2_table(26) := '2020202020202020202020206C546F70203D206C436F6E7461696E65722E746F703B5C6E5C7420202020202020207D20656C7365207B5C6E5C742020202020202020202020206C546F70203D206C56696577706F72742E746F703B5C6E5C742020202020';
wwv_flow_api.g_varchar2_table(27) := '2020207D5C6E5C6E5C7420202020202020202F2F20496620626F74746F6D206F6620636F6E7461696E65722069732076697369626C652C2075736520746861742061732074686520626F74746F6D2C206F7468657277697365207573652076696577706F';
wwv_flow_api.g_varchar2_table(28) := '727420626F74746F6D5C6E5C74202020202020202069662028206C436F6E7461696E65722E626F74746F6D203C206C56696577706F72742E626F74746F6D2029207B5C6E5C742020202020202020202020206C426F74746F6D203D206C436F6E7461696E';
wwv_flow_api.g_varchar2_table(29) := '65722E626F74746F6D3B5C6E5C7420202020202020207D20656C7365207B5C6E5C742020202020202020202020206C426F74746F6D203D206C56696577706F72742E626F74746F6D3B5C6E5C7420202020202020207D5C6E5C7420202020202020206C59';
wwv_flow_api.g_varchar2_table(30) := '506F736974696F6E203D2028206C426F74746F6D202D206C546F702029202F20323B5C6E5C6E5C7420202020202020202F2F20496620746F70206F6620636F6E7461696E6572206973206E6F742076697369626C652C205920706F736974696F6E206E65';
wwv_flow_api.g_varchar2_table(31) := '65647320746F2061646420616E206F666673657420657175616C2068696464656E20636F6E7461696E6572206865696768742C5C6E5C7420202020202020202F2F207468697320697320726571756972656420626563617573652077652061726520706F';
wwv_flow_api.g_varchar2_table(32) := '736974696F6E696E6720696E2074686520636F6E7461696E657220656C656D656E745C6E5C7420202020202020206C594F6666736574203D206C56696577706F72742E746F70202D206C436F6E7461696E65722E746F703B5C6E5C742020202020202020';
wwv_flow_api.g_varchar2_table(33) := '69662028206C594F6666736574203E20302029207B5C6E5C742020202020202020202020206C59506F736974696F6E203D206C59506F736974696F6E202B206C594F66667365743B5C6E5C7420202020202020207D5C6E5C6E5C7420202020202020206C';
wwv_flow_api.g_varchar2_table(34) := '5370696E6E6572242E706F736974696F6E287B5C6E5C742020202020202020202020206D793A2020202020202020205C2263656E7465725C222C5C6E5C7420202020202020202020202061743A2020202020202020205C226C6566742B35302520746F70';
wwv_flow_api.g_varchar2_table(35) := '2B5C22202B206C59506F736974696F6E202B205C2270785C222C5C6E5C742020202020202020202020206F663A2020202020202020206C436F6E7461696E6572242C5C6E5C74202020202020202020202020636F6C6C6973696F6E3A20205C226669745C';
wwv_flow_api.g_varchar2_table(36) := '225C6E5C7420202020202020207D293B5C6E5C74202020207D5C6E5C6E5C742020202072657475726E206C5370696E6E6572243B5C6E5C747D3B5C6E5C6E5C6E5C6E5C742F2F6368616E67652032207374617274732068657265202D2D2D2D2D2D2D2D2D';
wwv_flow_api.g_varchar2_table(37) := '2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D5C6E5C7424282723617065782D7574696C732D7370696E6E65722D63737327292E72656D6F766528293B5C6E5C6E5C746966287370696E6E6572435353297B5C6E5C745C7476617220746F4170';
wwv_flow_api.g_varchar2_table(38) := '70656E64203D20273C7374796C652069643D5C22617065782D7574696C732D7370696E6E65722D6373735C223E272B207370696E6E6572435353202B273C2F7374796C653E273B5C6E5C745C742428276865616427292E617070656E6428746F41707065';
wwv_flow_api.g_varchar2_table(39) := '6E64293B5C6E5C747D5C6E5C742F2F6368616E6765203220656E64732068657265202D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D5C6E7D3B5C6E5C6E5C6E5C6E225D2C2266696C65223A227363726970742E6A73';
wwv_flow_api.g_varchar2_table(40) := '227D';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(50140873007339085)
,p_plugin_id=>wwv_flow_api.id(50132478039169497)
,p_file_name=>'js/script.js.map'
,p_mime_type=>'application/octet-stream'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
